---
title: '[공지] 네이버페이 결제 오류'
category: 공지사항
tags:
  - 공지사항
searchTags:
  - 네이버페이 오류
  - 결제오류
  - 오류
  - '네이버페이 '
datetime: 2024-08-15T14:00:34.634Z
---

**안녕하세요, 포트원 고객지원팀입니다.**

**2024년 08월 15일 21시 52분 부터 23시 59분 까지 네이버페이 내부적으로 오류가 발생된 것으로 전달 받아 공유/안내드립니다.**

**아래 내용 참고부탁드립니다.**

---

안녕하세요, 네이버페이입니다.

아래와 같은 오류 현상이 발생하여 긴급 복구되었습니다.

서비스 이용에 불편을 드려 대단히 죄송합니다.

**\[오류 현상]** **네이버페이 결제 시 결제 오류**

\[발생 시간] 2024년 8월 15일 21시 52분 \~ 23시 59분

보다 안정적인 서비스 체공을 위해 더욱 노력하겠습니다.

관련하여 추가적인 문의는 네이버페이 [일대일문의](https://help.admin.pay.naver.com/mail/form.help)로 문의 부탁 드립니다.
감사합니다.

\[최초 오류 공지 등록 시간 : 2024년 8월 15일 22시 19분].

**[네이버페이 공지사항 보러가기 ↗](https://admin.pay.naver.com/notice/view?id=200018982)**
